<?php

/**
 *  twentyeleven for xili functions - + exemple de deux menus ajoutés
 *
 */
function twentyeleven_xilidev_setup () {
	global $wp_locale;
	load_theme_textdomain( 'twentyeleven', STYLESHEETPATH . '/langs' ); // now use .mo of child
	
	$xili_functionsfolder = get_stylesheet_directory() . '/functions-xili' ; 
	if (file_exists($xili_functionsfolder . '/multilingual-functions.php') && class_exists('xili_language')) {
		require_once ($xili_functionsfolder . '/multilingual-functions.php');
	}
	
}

/* actions and filters*/
add_action( 'after_setup_theme', 'twentyeleven_xilidev_setup', 11 );
add_action( 'wp_head', 'special_head' );

define('XILI_CATS_ALL','0');
define('TWENTYELEVEN_XILI_VER', '1.3'); // as style.css


/**
 * define when search form is completed by radio buttons to sub-select language when searching
 *
 */
function special_head() {
	// to change search form of widget
	// if ( is_front_page() || is_category() || is_search() )
	echo "<!-- Website powered with child-theme twentyeleven-xili v. ".TWENTYELEVEN_XILI_VER." of dev.xiligroup.com -->\n";
	if ( is_search() ) {
	 	add_filter('get_search_form', 'my_langs_in_search_form_2011', 10, 1); // in multilingual-functions.php
	}
}


add_action ( 'init', 'xili_create_menu_locations', 100 );

/**
 * filter to create one menu per language for dashboard
 * detect the default one created by theme ($menu_locations_keys[0])
 * @since 0.9.7
 * @updated 1.0.2
 */


function xili_create_menu_locations () {
	$xili_theme_options = xili_twentyeleven_get_theme_options() ; 
	if ( isset ( $xili_theme_options['nav_menus'] ) && $xili_theme_options['nav_menus'] == 'nav_menus' ) {  // ok for automatic insertion of one menu per lang...
		$menu_locations = get_registered_nav_menus() ; 
		$menu_locations_keys =  array_keys( $menu_locations );
		if ( class_exists('xili_language') ) {
			global $xili_language ;
			$default = 'en_us'; // currently the default language of theme in core WP
			$language_xili_settings = get_option('xili_language_settings');
			$language_slugs_list =  array_keys ( $language_xili_settings['langs_ids_array'] ) ;
			$oneloc = $menu_locations_keys[0]; // primary
			foreach ( $language_slugs_list as $slug ) {
				$one_menu_location = $oneloc.'_'.$slug ; 
				if ( $slug != $default ) {
					register_nav_menu ( $one_menu_location,  sprintf( __('%s for %s','twentyeleven'), $menu_locations[$oneloc], $slug ) );
				}
			}
		} 
	}
}


/**
 * filter to avoid modifying theme's header and changes 'virtually' location for each language
 * @since 0.9.7
 */

add_filter ( 'wp_nav_menu_args', 'xili_wp_nav_menu_args' ); // called at line #145 in nav-menu-template.php

function xili_wp_nav_menu_args ( $args ) {
	if ( class_exists('xili_language') ) {
		global $xili_language ;
		$default = 'en_us'; // currently the default language of theme as in core WP
		$slug = the_curlang();
		if ( $default != $slug ) {
			$theme_location = $args['theme_location'];
			if ( has_nav_menu ( $theme_location.'_'.$slug ) ) { // only if a menu is set by webmaster in menus dashboard
				$args['theme_location'] = $theme_location .'_'.$slug ;
			}	
		}
	}	
	return $args;
}


/**
 * dynamic style for flag depending current list 
 *
 * @since 1.0.2 - add #access
 *
 */
function twentyeleven_flags_style () {
	if ( class_exists('xili_language') ) {
		global $xili_language ;
		$language_xili_settings = get_option('xili_language_settings'); 
		if ( !is_array( $language_xili_settings['langs_ids_array'] ) ) { 
			$xili_language->get_lang_slug_ids(); // update array when no lang_perma 110830 thanks to Pierre
			update_option( 'xili_language_settings', $xili_language->xili_settings );
			$language_xili_settings = get_option('xili_language_settings');
		}
	
		$language_slugs_list =  array_keys ( $language_xili_settings['langs_ids_array'] ) ;
		$xili_theme_options = xili_twentyeleven_get_theme_options() ; // see below
		
		if ( !isset( $xili_theme_options['no_flags'] ) || $xili_theme_options['no_flags'] != 'hidden_flags' ) {
		?>
		<style type="text/css">
		<?php 
		
		$path = get_stylesheet_directory_uri();
		
		$ulmenus = array();
		foreach ( $language_slugs_list as $slug ) {
			echo "#access ul.menu li.lang-{$slug} a {background: transparent url('{$path}/images/flags/{$slug}.png') no-repeat center 16px; padding:0 !important;}\n";
			echo "#access li.lang-{$slug}:hover > a {background:  #efefef url('{$path}/images/flags/{$slug}.png') no-repeat center 16px !important;}\n";
			$ulmenus[] = "#access ul.menu li.lang-{$slug}";
		} 
			echo implode (', ', $ulmenus ) . " {text-indent:-9999px; width:24px; }\n";
		?>
		</style>
		<?php
		}
	}
}

add_action( 'wp_head', 'twentyeleven_flags_style' );


/**
 *
 *
 */
function single_lang_dir($post_id) {
	$langdir = ((function_exists('get_cur_post_lang_dir')) ? get_cur_post_lang_dir($post_id) : array());
	if ( isset($langdir['direction']) ) return $langdir['direction'];
} 

function twentyeleven_xili_credits () {
	printf( __("Multilingual child theme of twentyeleven by %s", 'twentyeleven' ),"<a href=\"http://dev.xiligroup.com\">dev.xiligroup</a> - " );
}

add_action ('twentyeleven_credits','twentyeleven_xili_credits');

/**
 * to avoid display of old xiliml_the_other_posts in singular
 * @since 1.1
 */
function xiliml_new_list() {
	if ( class_exists('xili_language') ) {
		global $xili_language;
	
		$xili_theme_options = xili_twentyeleven_get_theme_options() ; // see below
		
		if ( $xili_theme_options['linked_posts'] == 'show_linked' ) {
			if (is_page() && is_front_page() ) {
				return false;
			} else {	
				return true;
			}
		}	

		if ( is_active_widget ( false, false, 'xili_language_widgets' ) ) {
			
			$xili_widgets = get_option('widget_xili_language_widgets', array());
			foreach ( $xili_widgets as $key => $arrprop ) {
				if ( $key != '_multiwidget' ) {
					if ( $arrprop['theoption'] == 'typeonenew' ) {  // widget with option for singular
						if ( is_active_widget( false, 'xili_language_widgets-'.$key, 'xili_language_widgets' ) ) return false ;
					}
				}
			}
		}
		
		if ( XILILANGUAGE_VER > '2.0.0' && isset($xili_language -> xili_settings['navmenu_check_options']) && in_array ('navmenu-1', $xili_language -> xili_settings['navmenu_check_options']['primary']) ) return false ;
		
	}
	return true ;
	
}

/**
 * Add our theme options page to the admin menu, including some help documentation.
 *
 * This function is attached to the admin_menu action hook.
 *
 * @since Twenty Eleven 1.0
 */
function xili_twentyeleven_theme_options_add_page() {
	global $xili_theme_page;
	$xili_theme_page = add_theme_page(
		__( 'xili Options', 'twentyeleven' ), // Name of page
		__( 'xili Options', 'twentyeleven' ), // Label in menu
		'edit_theme_options',                  // Capability required
		'xili_theme_options',                       // Menu slug, used to uniquely identify the page
		'xili_theme_options_render_page'            // Function that renders the options page
	);
	add_action('load-'.$xili_theme_page, 'xili_twentyeleven_theme_options_help_page');
}

add_action( 'admin_menu', 'xili_twentyeleven_theme_options_add_page' );


function xili_twentyeleven_theme_options_help_page () {
	global $xili_theme_page;
	$screen = get_current_screen();
	
	if ( $screen->id != $xili_theme_page )
        return;
	$help = '<p>' . __( 'Some themes provide customization options that are grouped together on a Theme Options screen. If you change themes, options may change or disappear, as they are theme-specific. Your current theme, Twenty Eleven, provides the following Theme Options:', 'twentyeleven' ) . '</p>' .
			'<ol>' .
				'<li>' . __( '<strong>Multilingual Flags style</strong>: Check if you want to hidden flags and see only language names. (no style generated)...', 'twentyeleven' ) . '</li>' .
				'<li>' . __( '<strong>Other posts in other languages links in singular (page or post)</strong>: Check if you want to show links of posts in other languages.', 'twentyeleven' ) . '</li>' .
				
			'</ol>' .
			'<p>' . __( 'Remember to click "Save Changes" to save any changes you have made to the theme options.', 'twentyeleven' ) . '</p>' .
			'<p><strong>' . __( 'For more information:', 'twentyeleven' ) . '</strong></p>' .
			'<p>' . __( '<a href="http://codex.wordpress.org/Appearance_Theme_Options_Screen" target="_blank">WP Documentation on Theme Options</a>', 'twentyeleven' ) . '</p>' .
			'<p>' . __( '<a href="http://wiki.xiligroup.org" target="_blank">Xili Wiki</a>', 'twentyeleven' ) . '</p>'.
			'<p>' . __( '<a href="http://forum2.dev.xiligroup.com" target="_blank">Xili Support Forums</a>', 'twentyeleven' ) . '</p>';

	$screen->add_help_tab(  array(
        'id'	=> $xili_theme_page,
        'title'	=> __('Help'),
        'content'	=>	$help	));
}


/**
 * Returns the options array for Twenty Eleven.
 *
 * @since Twenty Eleven 1.0
 *
 * 
 *
 */
function xili_theme_options_render_page() {
	?>
	<div class="wrap">
		<?php screen_icon(); 
		$theme = ( function_exists('wp_get_theme')) ? wp_get_theme() : get_current_screen(); // WP 3.4
		?>
		<h2><?php printf( __( '%s Theme Options for multilingual features', 'twentyeleven' ), $theme ); ?></h2>
		<?php settings_errors(); ?>

		<form method="post" action="options.php">
			<?php
				settings_fields( 'xili_twentyeleven_options' ); // as in register_settings below
				$options = xili_twentyeleven_get_theme_options();
				$default_options = xili_twentyeleven_get_default_theme_options();
				$no_flags = isset( $options['no_flags'] ) ? $options['no_flags'] : "";
				$linked_posts = isset( $options['linked_posts'] ) ? $options['linked_posts'] : "";
				$nav_menus = isset( $options['nav_menus'] ) ? $options['nav_menus'] : "";
				$menu_locations = get_registered_nav_menus() ;
				$navmenu_count =  0 ;
				foreach ( $menu_locations as $one_key => $one_location ) { 
						if ( false === strpos( $one_key , '_' ) ) $navmenu_count ++ ; // only core nav menu
				}
				
				
			?>
			<table class="form-table">

				<tr valign="top" class="image-radio-option color-scheme"><th scope="row"><?php _e( 'Style of languages in menu', 'twentyeleven' ); ?></th>
					<td>
						<fieldset><legend class="screen-reader-text"><span><?php _e( 'Flags hidden', 'twentyeleven' ); ?></span></legend>
							<label for="xili_twentyeleven_theme_options[no_flags]" class="selectit"><input name="xili_twentyeleven_theme_options[no_flags]" <?php checked( $no_flags, "hidden_flags" ); ?> type="checkbox" value="hidden_flags" /><?php _e( 'Flags hidden', 'twentyeleven' ); ?></label>
						</fielset>
					</td>
				</tr>
				<tr valign="top" class="image-radio-option color-scheme"><th scope="row"><?php _e( 'Show Other Posts links in meta in single', 'twentyeleven' ); ?></th>
					<td>
						<fieldset><legend class="screen-reader-text"><span><?php _e( 'Show linked posts', 'twentyeleven' ); ?></span></legend>
							<label for="xili_twentyeleven_theme_options[linked_posts]" class="selectit"><input name="xili_twentyeleven_theme_options[linked_posts]" <?php checked( $linked_posts, "show_linked" ); ?> type="checkbox" value="show_linked" /><?php _e( 'Show', 'twentyeleven' ); ?></label>
						</fielset>
					</td>
				</tr>
				<tr valign="top" class="image-radio-option color-scheme"><th scope="row"><?php _e( 'Instantiate nav menu for each language', 'twentyeleven' ); ?></th>
					<td>
						<fieldset><legend class="screen-reader-text"><span><?php _e( 'Instantiate nav menus', 'twentyeleven' ); ?></span></legend>
							<label for="xili_twentyeleven_theme_options[nav_menus]" class="selectit"><input name="xili_twentyeleven_theme_options[nav_menus]" <?php checked( $nav_menus, "nav_menus" ); ?> type="checkbox" value="nav_menus" /><?php _e( 'Instantiate', 'twentyeleven' ); ?></label>
						</fielset>
					</td>
				</tr>
				<?php 
				
				if ( $navmenu_count > 1 )  {
				?>
				<tr valign="top" class="image-radio-option color-scheme"><th scope="row"><?php printf (__( 'Enable (or not) language instantiation for these registered menus<br /> After changes saved, <a href="%s" >go to Nav Menus</a> and save theme locations', 'twentyeleven' ) , 'nav-menus.php'); ?></th>
					<td>
					<?php foreach ( $menu_locations as $one_key => $one_location ) { 
						if ( false === strpos( $one_key , '_' ) ) {
							$indice = 'nav_menu_'.$one_key ;
							$nav_value = isset( $options[$indice] ) ? $options[$indice] : "";
						?>
						<fieldset>
							<label for="xili_twentyeleven_theme_options[<?php echo $indice ?>]" class="selectit"><input name="xili_twentyeleven_theme_options[<?php echo $indice ?>]" <?php checked( $nav_value, "nav_menu" ); ?> type="checkbox" value="nav_menu" /><?php echo $one_location ; ?></label>
						</fielset>
					<?php } } ?>	
					</td>
				</tr>
				
				<?php } ?>
			</table>
			<p><small>twentyeleven-xili v. <?php echo TWENTYELEVEN_XILI_VER; ?> , a multilingual child example by <a href="http://2011.wpmu.xilione.com" >dev.xiligroup.com</a> (©2011-2012)</small></p>
			<?php submit_button(); ?>
		</form>
	</div>
<?php
}

/**
 * Returns the options array for Twenty Eleven.
 *
 * @since Twenty Eleven 1.0
 */
function xili_twentyeleven_get_theme_options() {
	return get_option( 'xili_twentyeleven_theme_options', xili_twentyeleven_get_default_theme_options() );
}

function xili_twentyeleven_get_default_theme_options() {
	return array( 'no_flags' => false , 'linked_posts' => 'show_linked',  'nav_menus' => false) ;
}

function xili_twentyeleven_theme_options_init() {

	// If we have no options in the database, let's add them now.
	if ( false === xili_twentyeleven_get_theme_options() )
		add_option( 'xili_twentyeleven_theme_options', xili_twentyeleven_get_default_theme_options() );

	register_setting(
		
		'xili_twentyeleven_options', // prefix xili_ to avoid conflict with parent - thanks to sylvia - Database option, see twentyeleven_get_theme_options()
		'xili_twentyeleven_theme_options'
	);
}
add_action( 'admin_init', 'xili_twentyeleven_theme_options_init' );

?>